***************************************************************************
* Replication .do file for:
* Gerber, Alan S., Gregory A. Huber, David Doherty, and Conor M. Dowling. 2011.
* "Personality Traits and the Consumption of Political Information." 
* American Politics Research 39 (1 January): 32-84.
* Source data is CCAP 2007/8 survey with missing value flags not set,
*  data release 2.1
***************************************************************************

clear
set mem 600m
set matsize 1000
use "ccap0001_common_output_r2_1_missingnotset.dta", clear

*** TIPI
****************************
**CONSTRUCT BIG FIVE ITEMS**
****************************
*All are 7 point scales, missing/skipped set to missing
#delimit ;

recode
profile40 profile41 profile42 profile43 profile44 profile45 profile46 profile47 profile48 profile49 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) (*=.), 
gen(b_p_extraverted b_p_critical b_p_dependable b_p_anxious b_p_open b_p_reserved 
    b_p_sympathetic b_p_disorganized b_p_calm b_p_conventional);

*generate reversed values of items that need to be reverse scored;

recode
b_p_disorganized b_p_conventional b_p_critical b_p_anxious b_p_reserved
(7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7) (*=.),
gen(b_p_disorganized_R b_p_conventional_R b_p_critical_R b_p_anxious_R b_p_reserved_R);

#delimit cr

*Items range from 0 to 1 -- higher values indicate more of the trait

*Big Five - conscientiousness
gen BF_conscientiousness = (((b_p_dependable + b_p_disorganized_R)/2)-1)/6
label var BF_conscientiousness "Conscientiousness (0-1)"

*Big Five - openness to experiences
gen BF_openness = (((b_p_open + b_p_conventional_R)/2)-1)/6
label var BF_openness "Openness (0-1)"

*Big Five - agreeableness
gen BF_agreeableness = (((b_p_sympathetic + b_p_critical_R)/2)-1)/6
label var BF_agreeableness "Agreeableness (0-1)"

*Big Five - emotional stability
gen BF_stability = (((b_p_calm + b_p_anxious_R)/2)-1)/6
label var BF_stability "Stability (0-1)"

*Big Five - extraversion
gen BF_extraversion = (((b_p_extraverted + b_p_reserved_R)/2)-1)/6
label var BF_extraversion "Extraversion (0-1)"

***************
***IDEOLOGY****
***************
* Ideology
recode bcap700s (1=2) (2=1) (3=0) (4=-1) (5=-2) (6=.) (8=.) (9=.), gen(b_ideol)
label var b_ideol "Ideology (-2=Very Cons.; 2=Very Lib.)"

tab b_ideol, gen(ideol)
label var ideol1 "Very Conservative (1=Yes)"
label var ideol2 "Conservative (1=Yes)"
label var ideol3 "Moderate (1=Yes)"
label var ideol4 "Liberal(1=Yes)"
label var ideol5 "Very Liberal (1=Yes)"
*drop moderates
rename ideol3 moderates

* Str. Ideology
gen b_ideolstr=abs(b_ideol)
label var b_ideolstr "Pre: Ideology Strength"

****************************
***DEMOGRAPHIC VARIABLES****
****************************
* State
* No missing values
quietly tab profile66, gen(stateC_)

* TIME ZONES
gen timezone = "Eastern" if stateC_1==1 | stateC_4==1 | stateC_7==1 | stateC_8==1 | stateC_9==1 | stateC_10==1 | stateC_11==1 | stateC_15==1 | stateC_18==1 | stateC_20==1 | stateC_21==1 | stateC_22==1 | stateC_23==1 | stateC_30==1 | stateC_31==1 | stateC_33==1 | stateC_34==1 | stateC_36==1 | stateC_39==1 | stateC_40==1 | stateC_41==1 | stateC_46==1 | stateC_47==1 | stateC_49==1
replace timezone = "Central" if stateC_14==1 | stateC_16==1 | stateC_17==1 | stateC_19==1 | stateC_24==1 | stateC_25==1 | stateC_26==1 | stateC_28==1 | stateC_35==1 | stateC_37==1 | stateC_42==1 | stateC_43==1 | stateC_44==1 | stateC_50==1
replace timezone = "Mountain" if stateC_6==1 | stateC_13==1 | stateC_27==1 | stateC_32==1 | stateC_45==1 | stateC_51==1
replace timezone = "Pacific" if stateC_3==1 | stateC_5==1 | stateC_29==1 | stateC_38==1 | stateC_48==1
replace timezone = "Alaskan" if stateC_2==1
replace timezone = "Hawaian" if stateC_12==1

* drop State5 indicator--California (dominant category when weighted)
drop stateC_5

* Region
* No missing values
gen regwest=0
gen regmidwest=0
gen regsouth=0
gen regnortheast=0
replace regwest=1 if profile66==2 | profile66==4 | profile66==6 | profile66==8 | profile66==15 | profile66==16 | profile66==30 | profile66==32 | profile66==35 | profile66==41 | profile66==49 | profile66==53 | profile66==56
replace regmidwest=1 if profile66==17 | profile66==18 | profile66==19 | profile66==20 | profile66==26 | profile66==27 | profile66==29 | profile66==31 | profile66==38 | profile66==39 | profile66==46 | profile66==55
replace regsouth=1 if profile66==1 | profile66==5 | profile66==12 | profile66==13 | profile66==21 | profile66==22 | profile66==28 | profile66==37 | profile66==40 | profile66==45 | profile66==47 | profile66==48 | profile66==51 | profile66==54 
replace regnortheast=1 if profile66==9 | profile66==10 | profile66==11 | profile66==23 | profile66==24 | profile66==25 | profile66==33 | profile66==34 | profile66==36 | profile66==42 | profile66==44 | profile66==50 

* Gender
* No missing values
recode profile54 (1=0) (2=1) (*=.), gen(female)
drop if female==.
label var female "Female = 1"

* Race
* No missing values
recode profile55 (1=1) (2/8=0) (*=.), gen(r_white)
drop if r_white==.
recode profile55 (1=0) (2=1) (3/8=0) (*=.), gen(r_black)
recode profile55 (1/2=0) (3=1) (4/8=0) (*=.), gen(r_hispanic)
recode profile55 (1/3=0) (4/8=1) (*=.), gen(r_other)
label var r_white "White = 1"
label var r_black "Black = 1"
label var r_hispanic "Hispanic = 1"
label var r_other "Other (Native American,Asian,Mixed,Other) = 1"

* Age
* No missing values
rename profile51 birthyr
label var birthyr "birth year"
gen age=2009-birthyr 
label var age "Age (Years)"
forvalues i=1/4{
gen agecat`i'=0
}
replace agecat1=1 if age<31
label var agecat1 "Age (<31)"
replace agecat2=1 if age>30 & age<41
label var agecat2 "Age (31-50)"
replace agecat3=1 if age>50 & age<66
label var agecat3 "Age (51-65)"
replace agecat4=1 if age>65
label var agecat4 "Age (66+)"

forvalues i=1/6{
gen agedec`i'=0
}
replace agedec1=1 if age<31
label var agedec1 "Age <31 (1=Yes)"
rename agedec1 omit_agedec1
replace agedec2=1 if age>30 & age<41
label var agedec2 "Age 31-40 (1=Yes)"
replace agedec3=1 if age>40 & age<51
label var agedec3 "Age 41-50 (1=Yes)"
replace agedec4=1 if age>50 & age<61
label var agedec4 "Age 51-60 (1=Yes)"
replace agedec5=1 if age>60 & age<71
label var agedec5 "Age 61-70 (1=Yes)"
replace agedec6=1 if age>70
label var agedec6 "Age 71+ (1=Yes)"

gen age2=(age^2)/100
label var age2 "Age^2/100"

* Education
* No missing values
recode profile57 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (*=.), gen(educ)
drop if educ==.
label var educ "Education (1=No HS; 6=Post-grad)"
tab educ, gen(educC_)
*drop category 3
drop educC_3
label var educC_1 "Educ<HS"
label var educC_2 "Educ=HS"
label var educC_4 "Educ=2 year college"
label var educC_5 "Educ=College"
label var educC_6 "Educ=Post Grad"

* Family Income
* Skipped/RF set to 15, plus indicator for missing
* Not asked is dropped/missing
recode profile59 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) (8=8) (9=9) (10=10) (11=11) (12=12) (13=13) (14=14) (15=15) (98=15), gen(income)
drop if income==.
gen incomemis = (income==15)
label var incomemis "Income Refused"
label var income "Income (1=<10k; 14=>150k; 15=RF)"

* Employment Status
* 5 skipped
recode profile60 (98=0), gen(employed)
label var employed "Employment status"
gen employedmis = 0
replace employedmis = 1 if employed==0
label var employedmis "Missing: Employed (1=Yes)"
gen employeddum = 0 if employed ==0
replace employeddum = 1 if employed >0
replace employeddum = 0 if employed ==4
label var employeddum "Employment status dummy, employed=1"
tab employed, gen(employ)
rename employ2 fulltime
label var fulltime "Working full time (1=Yes)"
rename employ3 parttime
label var parttime "Working part time (1=Yes)"
gen unemployed = employ4
replace unemployed = 1 if employ5 ==1
replace unemployed = 1 if employ7 ==1
replace unemployed = 1 if employ8 ==1
replace unemployed = 1 if employ9 ==1
replace unemployed = 1 if employ10 ==1
replace unemployed = 1 if employ1 ==1
label var unemployed "Unemployed, temporarily laid off, other, or missing (1=Yes)"
rename employ6 retired
label var retired "Retired (1=Yes)"

***********************
***MEDIA CONSUMPTION***
***********************

* INTERNET USE, LAST 7 DAYS
set more 1
foreach i in b j m {
recode `i'cap1_1-`i'cap1_11 (2=0) (9=.)
}
rename bcap1_1 b_inetmovi
rename bcap1_2 b_inetvaca
rename bcap1_3 b_inetrest
rename bcap1_4 b_inetdirec
rename bcap1_5 b_inetpresearch
rename bcap1_6 b_inetcommwfrds
rename bcap1_7 b_inetbills
rename bcap1_8 b_inetnews
rename bcap1_9 b_inetsprts
rename bcap1_10 b_inetshop
rename bcap1_11 b_inetother

label var b_inetnews "Internet - news (last 7 days), 1=Yes"

rename jcap1_1 j_inetmovi
rename jcap1_2 j_inetvaca
rename jcap1_3 j_inetrest
rename jcap1_4 j_inetdirec
rename jcap1_5 j_inetpresearch
rename jcap1_6 j_inetcommwfrds
rename jcap1_7 j_inetbills
rename jcap1_8 j_inetnews
rename jcap1_9 j_inetsprts
rename jcap1_10 j_inetshop
rename jcap1_11 j_inetother

rename mcap1_1 m_inetmovi
rename mcap1_2 m_inetvaca
rename mcap1_3 m_inetrest
rename mcap1_4 m_inetdirec
rename mcap1_5 m_inetpresearch
rename mcap1_6 m_inetcommwfrds
rename mcap1_7 m_inetbills
rename mcap1_8 m_inetnews
rename mcap1_9 m_inetsprts
rename mcap1_10 m_inetshop
rename mcap1_11 m_inetother

* TV WATCHING, LAST 7 DAYS
set more 1
foreach i in b m {
recode `i'cap2_1-`i'cap2_9 (2=0) (9=.)
}
rename bcap2_1 b_tvsprts
rename bcap2_2 b_tvmovie
rename bcap2_3 b_tvprime
rename bcap2_4 b_tvnews
rename bcap2_5 b_tvltnght
rename bcap2_6 b_tvdaytalk
rename bcap2_7 b_tvpoltalk
rename bcap2_8 b_tvsatire
rename bcap2_9 b_tvother

label var b_tvsprts "TV - sports (last 7 days), 1=Yes"
label var b_tvmovie "TV - movies (last 7 days), 1=Yes"
label var b_tvprime "TV - primetime (last 7 days), 1=Yes"
label var b_tvnews "TV - news programs (last 7 days), 1=Yes"
label var b_tvltnght "TV - late night (last 7 days), 1=Yes"
label var b_tvpoltalk "TV - political talk (last 7 days), 1=Yes"
label var b_tvsatire "TV - satire (last 7 days), 1=Yes"
label var b_tvdaytalk "TV - daytime talk (last 7 days), 1=Yes"

rename mcap2_1 m_tvsprts
rename mcap2_2 m_tvmovie
rename mcap2_3 m_tvprime
rename mcap2_4 m_tvnews
rename mcap2_5 m_tvltnght
rename mcap2_6 m_tvdaytalk
rename mcap2_7 m_tvpoltalk
rename mcap2_8 m_tvsatire
rename mcap2_9 m_tvother

* TALK ABOUT, LAST 7 DAYS
set more 1
foreach i in b m {
recode `i'cap3_1-`i'cap3_10 (2=0) (9=.)
}
rename bcap3_1 b_talksprts
rename bcap3_2 b_talkmovie
rename bcap3_3 b_talktv
rename bcap3_4 b_talkpolitics
rename bcap3_5 b_talkcars
rename bcap3_6 b_talkfood
rename bcap3_7 b_talkvaca
rename bcap3_8 b_talkshop
rename bcap3_9 b_talkhobbies
rename bcap3_10 b_talkother

rename mcap3_1 m_talksprts
rename mcap3_2 m_talkmovie
rename mcap3_3 m_talktv
rename mcap3_4 m_talkpolitics
rename mcap3_5 m_talkcars
rename mcap3_6 m_talkfood
rename mcap3_7 m_talkvaca
rename mcap3_8 m_talkshop
rename mcap3_9 m_talkhobbies
rename mcap3_10 m_talkother

* NEWSPAPER READING
recode mcap815 scap815 (8=.) (9=.)
rename mcap815 m_readnews
rename scap815 s_readnews

**newspaper (last week)
*create dummy
gen m_newspaper = 0 if m_readnews ~=.
replace m_newspaper = 1 if m_readnews >0 & m_readnews ~=.
replace m_newspaper =. if b_tvnews ==.
label var m_newspaper "Read newspaper in last week (1=Yes)"

* FREQ INTERNET USE FOR POLITICS, LAST SEVEN DAYS (0 to 7)
recode bcap820 bcap821 bcap822 bcap823 (8=.) (9=.)
rename bcap820 b_visitnews
rename bcap821 b_visitpolblogs
rename bcap822 b_postnewsblogs
rename bcap823 b_emailpolitics

recode mcap820 mcap821 mcap822 mcap823 (8=.) (9=.)
rename mcap820 m_visitnews
rename mcap821 m_visitpolblogs
rename mcap822 m_postnewsblogs
rename mcap823 m_emailpolitics

recode scap820 scap821 scap822 scap823 (8=.) (9=.)
rename scap820 s_visitnews
rename scap821 s_visitpolblogs
rename scap822 s_postnewsblogs
rename scap823 s_emailpolitics

gen anynewsconslw = 0 if m_newspaper ~=.
replace anynewsconslw = 1 if m_newspaper ==1
replace anynewsconslw = 1 if b_inetnews ==1 & m_newspaper ~=.
replace anynewsconslw = 1 if b_tvnews==1 & m_newspaper ~=.
label var anynewsconslw "Any news consumption in last week (TV/Internet/Newspaper), 1=Yes"
gen anynewsconslw2 = 0 if m_newspaper ~=.
replace anynewsconslw2 = 1 if m_newspaper ==1
replace anynewsconslw2 = 1 if b_inetnews ==1 & m_newspaper ~=.
replace anynewsconslw2 = 1 if b_tvnews==1 & m_newspaper ~=.
replace anynewsconslw2 = 1 if b_tvpoltalk ==1 & m_newspaper ~=.
label var anynewsconslw2 "Any news consumption in last week (TV/Internet/Newspaper/Political Talk), 1=Yes"

*Amount/variety of news consumption
gen amtnews = m_newspaper+b_inetnews+b_tvnews+b_tvpoltalk
label var amtnews "Amount of news consumption in last week, number of mediums (0 to 4)"

* LEVEL OF INTEREST IN POLITICS
set more 1
foreach i in b j m s o {
recode `i'cap813 (1=3) (2=2) (3=1) (4=1) (*=.), gen(`i'_polinterest)
}
label var b_polinterest "Interest in Politics (1=not that much/NS, 2=somewhat, 3=very much), baseline"
label var j_polinterest "Interest in Politics (1=not that much/NS, 2=somewhat, 3=very much), january"
label var m_polinterest "Interest in Politics (1=not that much/NS, 2=somewhat, 3=very much), march"
label var s_polinterest "Interest in Politics (1=not that much/NS, 2=somewhat, 3=very much), sept."
label var o_polinterest "Interest in Politics (1=not that much/NS, 2=somewhat, 3=very much), october"

recode ocap802a (1=4) (2=3) (3=2) (4=1) (5=1) (*=.), gen(o_govinterest)
*label var o_govinterest "Interest in Public Affairs (1=hardly at all/DK, 2=only now and then, 3=some of the time, 4=most of the time), october"
label var o_govinterest "Interest in Public Affairs (1=hardly at all/DK, 4=most of the time), october"

*POLITICAL KNOWLEDGE
* Political Knowledge Questions - House/Senate Jobs
recode profile101 (1=1) (2=0) (3=0) (8=0) (9=.), gen(dingell)
label var dingell "Know Dingell's job (Right=1, Wrong=0)"

recode profile102 (1=1) (2=0) (3=0) (8=0) (9=.), gen(pelosi)
label var pelosi "Know Pelosi's job (Right=1, Wrong=0)"

recode profile103 (3=1) (2=0) (1=0) (8=0) (9=.), gen(gates)
label var gates "Know Gates' job (Right=1, Wrong=0)"

recode profile104 (1=1) (2=0) (3=0) (8=0) (9=.), gen(boehner)
label var boehner "Know Boehner's job (Right=1, Wrong=0)"

recode profile105 (2=1) (1=0) (3=0) (8=0) (9=.), gen(collins)
label var collins "Know Collins' job (Right=1, Wrong=0)"

recode profile106 (1=1) (2=0) (3=0) (8=0) (9=.), gen(waxman)
label var waxman "Know Waxman's job (Right=1, Wrong=0)"

recode profile107 (2=1) (1=0) (3=0) (8=0) (9=.), gen(kyl)
label var kyl "Know Kyl's job (Right=1, Wrong=0)"

recode profile108 (1=1) (2=0) (3=0) (8=0) (9=.), gen(kucinich)
label var kucinich "Know Kucinich's job (Right=1, Wrong=0)"

recode profile109 (2=1) (1=0) (3=0) (8=0) (9=.), gen(leahy)
label var leahy "Know Leahy's job (Right=1, Wrong=0)"

recode profile110 (2=1) (1=0) (3=0) (8=0) (9=.), gen(kennedy)
label var kennedy "Know Kennedy's job (Right=1, Wrong=0)"

recode profile116 (2=1) (1=0) (3=0) (4=0) (5=0) (8=0) (9=.), gen(rice)
label var rice "Know Rice's job (Right=1, Wrong=0)"

* Political Knowledge Scale - Positions Correct (10, not rice)
gen answeredall = 0
replace answeredall = 1 if dingell ~=. & pelosi ~=. & gates ~=. & boehner ~=. & collins ~=. & waxman ~=. & kyl ~=. & kucinich ~=. & leahy ~=. & kennedy ~=.

gen polknowledge = (dingell+pelosi+gates+boehner+collins+waxman+kyl+kucinich+leahy+kennedy) if answeredall ==1
label var polknowledge "Number position questions correct (0-10)"
egen poltrivia=std(polknowledge)
label var poltrivia "Political Knowledge (standardized index) [-1.67 to 1.68]"

* Political Knowledge Questions - Guantanamo Bay
recode profile117 (1=1) (2=0) (8=0) (9=.), gen(guantanamo)
label var guantanamo "Heard of Guantanamo Bay (Right=1, Wrong=0)"

recode profile117a (1=1) (2=0) (3=0) (4=0) (5=0) (8=0) (9=.), gen(guanpurpose)
label var guanpurpose "Know purpose of Guantanamo Bay (Right=1, Wrong=0)"

* Political Knowledge Questions - Other
recode profile213 (1=1) (2=0) (3=0) (4=0) (8=0) (9=.), gen(imports)
label var imports "Say US has been importing more in last couple of years (Right=1, Wrong=0)"

recode profile214 (2=1) (1=0) (3=0) (4=0) (8=0) (9=.), gen(usdollar)
label var usdollar "Know US dollar is weaker in comparison (Right=1, Wrong=0)"

*************
** TV GRID **
*************
* TV GRID
set more 1
foreach i in b j m s o {
recode `i'cap801_1-`i'cap801_6 `i'cap802_1-`i'cap802_6 `i'cap803_1-`i'cap803_6 `i'cap804_1-`i'cap804_6 `i'cap805_1-`i'cap805_6 `i'cap806_1-`i'cap806_6 `i'cap807_1-`i'cap807_6 `i'cap808_1-`i'cap808_6 `i'cap809_1-`i'cap809_6 `i'cap810_1-`i'cap810_6 `i'cap811_1-`i'cap811_6 (2=0) (9=.)
}
rename bcap801_1 b_abc400
rename bcap801_2 b_cbs400
rename bcap801_3 b_nbc400
rename bcap801_4 b_fox400
rename bcap801_5 b_pbs400
rename bcap801_6 b_other400

rename bcap802_1 b_abc430
rename bcap802_2 b_cbs430
rename bcap802_3 b_nbc430
rename bcap802_4 b_fox430
rename bcap802_5 b_pbs430
rename bcap802_6 b_other430

rename bcap803_1 b_abc500
rename bcap803_2 b_cbs500
rename bcap803_3 b_nbc500
rename bcap803_4 b_fox500
rename bcap803_5 b_pbs500
rename bcap803_6 b_other500

rename bcap804_1 b_abc530
rename bcap804_2 b_cbs530
rename bcap804_3 b_nbc530
rename bcap804_4 b_fox530
rename bcap804_5 b_pbs530
rename bcap804_6 b_other530

rename bcap805_1 b_abc600
rename bcap805_2 b_cbs600
rename bcap805_3 b_nbc600
rename bcap805_4 b_fox600
rename bcap805_5 b_pbs600
rename bcap805_6 b_other600

rename bcap806_1 b_abc630
rename bcap806_2 b_cbs630
rename bcap806_3 b_nbc630
rename bcap806_4 b_fox630
rename bcap806_5 b_pbs630
rename bcap806_6 b_other630

rename bcap807_1 b_abc700
rename bcap807_2 b_cbs700
rename bcap807_3 b_nbc700
rename bcap807_4 b_fox700
rename bcap807_5 b_pbs700
rename bcap807_6 b_other700

rename bcap808_1 b_abc800
rename bcap808_2 b_cbs800
rename bcap808_3 b_nbc800
rename bcap808_4 b_fox800
rename bcap808_5 b_pbs800
rename bcap808_6 b_other800

rename bcap809_1 b_abc900
rename bcap809_2 b_cbs900
rename bcap809_3 b_nbc900
rename bcap809_4 b_fox900
rename bcap809_5 b_pbs900
rename bcap809_6 b_other900

rename bcap810_1 b_abc1000
rename bcap810_2 b_cbs1000
rename bcap810_3 b_nbc1000
rename bcap810_4 b_fox1000
rename bcap810_5 b_pbs1000
rename bcap810_6 b_other1000

rename bcap811_1 b_abc1100
rename bcap811_2 b_cbs1100
rename bcap811_3 b_nbc1100
rename bcap811_4 b_fox1100
rename bcap811_5 b_pbs1100
rename bcap811_6 b_other1100

rename jcap801_1 j_abc400
rename jcap801_2 j_cbs400
rename jcap801_3 j_nbc400
rename jcap801_4 j_fox400
rename jcap801_5 j_pbs400
rename jcap801_6 j_other400

rename jcap802_1 j_abc430
rename jcap802_2 j_cbs430
rename jcap802_3 j_nbc430
rename jcap802_4 j_fox430
rename jcap802_5 j_pbs430
rename jcap802_6 j_other430

rename jcap803_1 j_abc500
rename jcap803_2 j_cbs500
rename jcap803_3 j_nbc500
rename jcap803_4 j_fox500
rename jcap803_5 j_pbs500
rename jcap803_6 j_other500

rename jcap804_1 j_abc530
rename jcap804_2 j_cbs530
rename jcap804_3 j_nbc530
rename jcap804_4 j_fox530
rename jcap804_5 j_pbs530
rename jcap804_6 j_other530

rename jcap805_1 j_abc600
rename jcap805_2 j_cbs600
rename jcap805_3 j_nbc600
rename jcap805_4 j_fox600
rename jcap805_5 j_pbs600
rename jcap805_6 j_other600

rename jcap806_1 j_abc630
rename jcap806_2 j_cbs630
rename jcap806_3 j_nbc630
rename jcap806_4 j_fox630
rename jcap806_5 j_pbs630
rename jcap806_6 j_other630

rename jcap807_1 j_abc700
rename jcap807_2 j_cbs700
rename jcap807_3 j_nbc700
rename jcap807_4 j_fox700
rename jcap807_5 j_pbs700
rename jcap807_6 j_other700

rename jcap808_1 j_abc800
rename jcap808_2 j_cbs800
rename jcap808_3 j_nbc800
rename jcap808_4 j_fox800
rename jcap808_5 j_pbs800
rename jcap808_6 j_other800

rename jcap809_1 j_abc900
rename jcap809_2 j_cbs900
rename jcap809_3 j_nbc900
rename jcap809_4 j_fox900
rename jcap809_5 j_pbs900
rename jcap809_6 j_other900

rename jcap810_1 j_abc1000
rename jcap810_2 j_cbs1000
rename jcap810_3 j_nbc1000
rename jcap810_4 j_fox1000
rename jcap810_5 j_pbs1000
rename jcap810_6 j_other1000

rename jcap811_1 j_abc1100
rename jcap811_2 j_cbs1100
rename jcap811_3 j_nbc1100
rename jcap811_4 j_fox1100
rename jcap811_5 j_pbs1100
rename jcap811_6 j_other1100

rename mcap801_1 m_abc400
rename mcap801_2 m_cbs400
rename mcap801_3 m_nbc400
rename mcap801_4 m_fox400
rename mcap801_5 m_pbs400
rename mcap801_6 m_other400

rename mcap802_1 m_abc430
rename mcap802_2 m_cbs430
rename mcap802_3 m_nbc430
rename mcap802_4 m_fox430
rename mcap802_5 m_pbs430
rename mcap802_6 m_other430

rename mcap803_1 m_abc500
rename mcap803_2 m_cbs500
rename mcap803_3 m_nbc500
rename mcap803_4 m_fox500
rename mcap803_5 m_pbs500
rename mcap803_6 m_other500

rename mcap804_1 m_abc530
rename mcap804_2 m_cbs530
rename mcap804_3 m_nbc530
rename mcap804_4 m_fox530
rename mcap804_5 m_pbs530
rename mcap804_6 m_other530

rename mcap805_1 m_abc600
rename mcap805_2 m_cbs600
rename mcap805_3 m_nbc600
rename mcap805_4 m_fox600
rename mcap805_5 m_pbs600
rename mcap805_6 m_other600

rename mcap806_1 m_abc630
rename mcap806_2 m_cbs630
rename mcap806_3 m_nbc630
rename mcap806_4 m_fox630
rename mcap806_5 m_pbs630
rename mcap806_6 m_other630

rename mcap807_1 m_abc700
rename mcap807_2 m_cbs700
rename mcap807_3 m_nbc700
rename mcap807_4 m_fox700
rename mcap807_5 m_pbs700
rename mcap807_6 m_other700

rename mcap808_1 m_abc800
rename mcap808_2 m_cbs800
rename mcap808_3 m_nbc800
rename mcap808_4 m_fox800
rename mcap808_5 m_pbs800
rename mcap808_6 m_other800

rename mcap809_1 m_abc900
rename mcap809_2 m_cbs900
rename mcap809_3 m_nbc900
rename mcap809_4 m_fox900
rename mcap809_5 m_pbs900
rename mcap809_6 m_other900

rename mcap810_1 m_abc1000
rename mcap810_2 m_cbs1000
rename mcap810_3 m_nbc1000
rename mcap810_4 m_fox1000
rename mcap810_5 m_pbs1000
rename mcap810_6 m_other1000

rename mcap811_1 m_abc1100
rename mcap811_2 m_cbs1100
rename mcap811_3 m_nbc1100
rename mcap811_4 m_fox1100
rename mcap811_5 m_pbs1100
rename mcap811_6 m_other1100

rename scap801_1 s_abc400
rename scap801_2 s_cbs400
rename scap801_3 s_nbc400
rename scap801_4 s_fox400
rename scap801_5 s_pbs400
rename scap801_6 s_other400

rename scap802_1 s_abc430
rename scap802_2 s_cbs430
rename scap802_3 s_nbc430
rename scap802_4 s_fox430
rename scap802_5 s_pbs430
rename scap802_6 s_other430

rename scap803_1 s_abc500
rename scap803_2 s_cbs500
rename scap803_3 s_nbc500
rename scap803_4 s_fox500
rename scap803_5 s_pbs500
rename scap803_6 s_other500

rename scap804_1 s_abc530
rename scap804_2 s_cbs530
rename scap804_3 s_nbc530
rename scap804_4 s_fox530
rename scap804_5 s_pbs530
rename scap804_6 s_other530

rename scap805_1 s_abc600
rename scap805_2 s_cbs600
rename scap805_3 s_nbc600
rename scap805_4 s_fox600
rename scap805_5 s_pbs600
rename scap805_6 s_other600

rename scap806_1 s_abc630
rename scap806_2 s_cbs630
rename scap806_3 s_nbc630
rename scap806_4 s_fox630
rename scap806_5 s_pbs630
rename scap806_6 s_other630

rename scap807_1 s_abc700
rename scap807_2 s_cbs700
rename scap807_3 s_nbc700
rename scap807_4 s_fox700
rename scap807_5 s_pbs700
rename scap807_6 s_other700

rename scap808_1 s_abc800
rename scap808_2 s_cbs800
rename scap808_3 s_nbc800
rename scap808_4 s_fox800
rename scap808_5 s_pbs800
rename scap808_6 s_other800

rename scap809_1 s_abc900
rename scap809_2 s_cbs900
rename scap809_3 s_nbc900
rename scap809_4 s_fox900
rename scap809_5 s_pbs900
rename scap809_6 s_other900

rename scap810_1 s_abc1000
rename scap810_2 s_cbs1000
rename scap810_3 s_nbc1000
rename scap810_4 s_fox1000
rename scap810_5 s_pbs1000
rename scap810_6 s_other1000

rename scap811_1 s_abc1100
rename scap811_2 s_cbs1100
rename scap811_3 s_nbc1100
rename scap811_4 s_fox1100
rename scap811_5 s_pbs1100
rename scap811_6 s_other1100

rename ocap801_1 o_abc400
rename ocap801_2 o_cbs400
rename ocap801_3 o_nbc400
rename ocap801_4 o_fox400
rename ocap801_5 o_pbs400
rename ocap801_6 o_other400

rename ocap802_1 o_abc430
rename ocap802_2 o_cbs430
rename ocap802_3 o_nbc430
rename ocap802_4 o_fox430
rename ocap802_5 o_pbs430
rename ocap802_6 o_other430

rename ocap803_1 o_abc500
rename ocap803_2 o_cbs500
rename ocap803_3 o_nbc500
rename ocap803_4 o_fox500
rename ocap803_5 o_pbs500
rename ocap803_6 o_other500

rename ocap804_1 o_abc530
rename ocap804_2 o_cbs530
rename ocap804_3 o_nbc530
rename ocap804_4 o_fox530
rename ocap804_5 o_pbs530
rename ocap804_6 o_other530

rename ocap805_1 o_abc600
rename ocap805_2 o_cbs600
rename ocap805_3 o_nbc600
rename ocap805_4 o_fox600
rename ocap805_5 o_pbs600
rename ocap805_6 o_other600

rename ocap806_1 o_abc630
rename ocap806_2 o_cbs630
rename ocap806_3 o_nbc630
rename ocap806_4 o_fox630
rename ocap806_5 o_pbs630
rename ocap806_6 o_other630

rename ocap807_1 o_abc700
rename ocap807_2 o_cbs700
rename ocap807_3 o_nbc700
rename ocap807_4 o_fox700
rename ocap807_5 o_pbs700
rename ocap807_6 o_other700

rename ocap808_1 o_abc800
rename ocap808_2 o_cbs800
rename ocap808_3 o_nbc800
rename ocap808_4 o_fox800
rename ocap808_5 o_pbs800
rename ocap808_6 o_other800

rename ocap809_1 o_abc900
rename ocap809_2 o_cbs900
rename ocap809_3 o_nbc900
rename ocap809_4 o_fox900
rename ocap809_5 o_pbs900
rename ocap809_6 o_other900

rename ocap810_1 o_abc1000
rename ocap810_2 o_cbs1000
rename ocap810_3 o_nbc1000
rename ocap810_4 o_fox1000
rename ocap810_5 o_pbs1000
rename ocap810_6 o_other1000

rename ocap811_1 o_abc1100
rename ocap811_2 o_cbs1100
rename ocap811_3 o_nbc1100
rename ocap811_4 o_fox1100
rename ocap811_5 o_pbs1100
rename ocap811_6 o_other1100

* Day of Week Respondent Took Survey (for each wave)
gen day_base_s = dow(dofc(profile73b))
gen day_base_e = dow(dofc(profile74b))
gen sameday_b = day_base_s-day_base_e
gen notsameday_b = 0 if sameday_b~=.
replace notsameday_b = 1 if sameday_b~=0 & sameday_b~=.

* Generate string variable with day of week (already lagged)
gen b_dayofweek ="."
replace b_dayofweek = "Sunday" if day_base_s == 1
replace b_dayofweek = "Monday" if day_base_s == 2
replace b_dayofweek = "Tuesday" if day_base_s == 3
replace b_dayofweek = "Wednesday" if day_base_s == 4
replace b_dayofweek = "Thursday" if day_base_s == 5
replace b_dayofweek = "Friday" if day_base_s == 6
replace b_dayofweek = "Saturday" if day_base_s == 0

tab day_base_s, gen(day_base_C_)
*Drop category for those who took survey on Sunday
drop day_base_C_1

gen date_base_s = day(dofc(profile73b))

gen day_jan_s = dow(dofc(profile73j))
gen day_jan_e = dow(dofc(profile74j))
gen sameday_j = day_jan_s-day_jan_e
gen notsameday_j = 0 if sameday_j~=.
replace notsameday_j = 1 if sameday_j~=0 & sameday_j~=.

gen day_mar_s = dow(dofc(profile73m))
gen day_mar_e = dow(dofc(profile74m))
gen sameday_m = day_mar_s-day_mar_e
gen notsameday_m = 0 if sameday_m~=.
replace notsameday_m = 1 if sameday_m~=0 & sameday_m~=.

tab day_mar_s, gen(day_mar_C_)
*Drop category for those who took survey on Sunday
drop day_mar_C_1

gen day_sep_s = dow(dofc(profile73s))
gen day_sep_e = dow(dofc(profile74s))
gen sameday_s = day_sep_s-day_sep_e
gen notsameday_s = 0 if sameday_s~=.
replace notsameday_s = 1 if sameday_s~=0 & sameday_s~=.
* Generate string variable with day of week (referring to yesterday's day)
gen s_dayofweek ="."
replace s_dayofweek = "Sunday" if day_sep_s == 1
replace s_dayofweek = "Monday" if day_sep_s == 2
replace s_dayofweek = "Tuesday" if day_sep_s == 3
replace s_dayofweek = "Wednesday" if day_sep_s == 4
replace s_dayofweek = "Thursday" if day_sep_s == 5
replace s_dayofweek = "Friday" if day_sep_s == 6
replace s_dayofweek = "Saturday" if day_sep_s == 0

tab day_sep_s, gen(day_sep_C_)
*Drop category for those who took survey on Sunday
drop day_sep_C_1

gen date_sep_s = day(dofc(profile73s))

gen day_oct_s = dow(dofc(profile73o))
gen day_oct_e = dow(dofc(profile74o))
gen sameday_o = day_oct_s-day_oct_e
gen notsameday_o = 0 if sameday_o~=.
replace notsameday_o = 1 if sameday_o~=0 & sameday_o~=.
* Generate string variable with day of week (already lagged)
gen o_dayofweek ="."
replace o_dayofweek = "Sunday" if day_oct_s == 1
replace o_dayofweek = "Monday" if day_oct_s == 2
replace o_dayofweek = "Tuesday" if day_oct_s == 3
replace o_dayofweek = "Wednesday" if day_oct_s == 4
replace o_dayofweek = "Thursday" if day_oct_s == 5
replace o_dayofweek = "Friday" if day_oct_s == 6
replace o_dayofweek = "Saturday" if day_oct_s == 0

tab day_oct_s, gen(day_oct_C_)
*Drop category for those who took survey on Sunday
drop day_oct_C_1

gen date_oct_s = day(dofc(profile73o))

* USE INDIVIDUALLY LABELED .DO FILES FOR EACH NETWORK AND WAVE *
*** MUCH OF THIS CODE WAS CREATED IN EXCEL, SEE FILE "TVgrid.xls" ***
*OCTOBER
run "TV Grids/tvgrid_october_abc.do"
run "TV Grids/tvgrid_october_cbs.do"
run "TV Grids/tvgrid_october_nbc.do"
run "TV Grids/tvgrid_october_fox.do"
run "TV Grids/tvgrid_october_pbs.do"

*Indicator for how many hours of ABC TV
gen o_howmuchtv_abc = (o_abc500*.5)+(o_abc530*.5)+(o_abc600*.5)+(o_abc630*.5)+o_abc700+o_abc800+o_abc900+o_abc1000+o_abc1100
label var o_howmuchtv_abc "Total Hours of TV Watching - ABC [October]"

*Indicator for watched any news on ABC
gen o_w_anyeveningnewsabc = o_w_localnewsabc if o_howmuchtv_abc~=.
replace o_w_anyeveningnewsabc = 1 if o_w_natlnewsabc ==1
label var o_w_anyeveningnewsabc "Watched any evening news - ABC [October]"

*Indicator for how many hours of NBC TV
gen o_howmuchtv_nbc = (o_nbc500*.5)+(o_nbc530*.5)+(o_nbc600*.5)+(o_nbc630*.5)+o_nbc700+o_nbc800+o_nbc900+o_nbc1000+o_nbc1100
label var o_howmuchtv_nbc "Total Hours of TV Watching - nbc [October]"

*Indicator for watched any news on NBC
gen o_w_anyeveningnewsnbc = o_w_localnewsnbc if o_howmuchtv_nbc~=.
replace o_w_anyeveningnewsnbc = 1 if o_w_natlnewsnbc ==1
label var o_w_anyeveningnewsnbc "Watched any evening news - NBC [October]"

*Indicator for how many hours of CBS TV
gen o_howmuchtv_cbs = (o_cbs500*.5)+(o_cbs530*.5)+(o_cbs600*.5)+(o_cbs630*.5)+o_cbs700+o_cbs800+o_cbs900+o_cbs1000+o_cbs1100
label var o_howmuchtv_cbs "Total Hours of TV Watching - cbs [October]"

*Indicator for watched any news on CBS
gen o_w_anyeveningnewscbs = o_w_localnewscbs if o_howmuchtv_cbs~=.
replace o_w_anyeveningnewscbs = 1 if o_w_natlnewscbs ==1
label var o_w_anyeveningnewscbs "Watched any evening news - CBS [October]"

*Indicator for how many hours of FOX TV
gen o_howmuchtv_fox = (o_fox500*.5)+(o_fox530*.5)+(o_fox600*.5)+(o_fox630*.5)+o_fox700+o_fox800+o_fox900+o_fox1000+o_fox1100
label var o_howmuchtv_fox "Total Hours of TV Watching - fox [October]"

*Indicator for how many hours of PBS TV
gen o_howmuchtv_pbs = (o_pbs500*.5)+(o_pbs530*.5)+(o_pbs600*.5)+(o_pbs630*.5)+o_pbs700+o_pbs800+o_pbs900+o_pbs1000+o_pbs1100
label var o_howmuchtv_pbs "Total Hours of TV Watching - pbs [October]"

*How Much TV, Other
gen o_howmuchtv_other = (o_other500*.5)+(o_other530*.5)+(o_other600*.5)+(o_other630*.5)+o_other700+o_other800+o_other900+o_other1000+o_other1100
label var o_howmuchtv_other "Total Hours of TV Watching - Other [October]"

*How Much TV, Overall Measure
gen o_howmuchtv_overall = o_howmuchtv_abc+o_howmuchtv_cbs+o_howmuchtv_nbc+o_howmuchtv_fox+o_howmuchtv_pbs+o_howmuchtv_other
label var o_howmuchtv_overall "Total Hours of TV Watching [October]"
recode o_howmuchtv_overall (0=0) (1=1)(2=2)(3=3)(4=4)(5=5)(6=6)(7=7) (.=.) (*=7)

*How Much TV, Better Overall Measure (Total Hours of TV Watching)
foreach i in 500 530 600 630 700 800 900 1000 1100 {
gen o_w_tv`i'=0
replace o_w_tv`i'=. if odisp==3
replace o_w_tv`i'=1 if (o_abc`i'==1) | (o_nbc`i'==1) | (o_cbs`i'==1) | (o_fox`i'==1) | (o_pbs`i'==1) | (o_other`i'==1)
label var o_w_tv`i' "Watched TV `i'pm"
}
gen o_w_tv_total = (o_w_tv500*.5)+(o_w_tv530*.5)+(o_w_tv600*.5)+(o_w_tv630*.5)+o_w_tv700+o_w_tv800+o_w_tv900+o_w_tv1000+o_w_tv1100
label var o_w_tv_total "Total Hours of TV Watching Yesterday (0 to 7) [October]"

** NEWS WATCHING INDICATORS
*Watched Any Evening News
egen o_w_anyeveningnews = rmean(o_w_anyeveningnewsabc o_w_anyeveningnewscbs o_w_anyeveningnewsnbc o_w_localnewsfox o_w_bbcworldnewspbs o_w_newspbs o_w_newshourpbs)
recode o_w_anyeveningnews (0=0) (.=.) (*=1), gen(o_anyeveningnews)
label var o_anyeveningnews "Watched Any (Local or National) Evening News Yesterday, 1=Yes [October]"

*Watched Any Local News
egen o_w_localnews = rmean(o_w_localnewsabc o_w_localnewscbs o_w_localnewsnbc o_w_localnewsfox)
recode o_w_localnews (0=0) (.=.) (*=1), gen(o_localnews)
label var o_localnews "Watched Any Local Evening News Yesterday, 1=Yes [October]"

*Watched Any National News
egen o_w_natlnews = rmean(o_w_natlnewsabc o_w_natlnewscbs o_w_natlnewsnbc o_w_newshourpbs)
recode o_w_natlnews (0=0) (.=.) (*=1), gen(o_natlnews)
label var o_natlnews "Watched Any National News Yesterday, 1=Yes [October]"

*Watched Any National News - Not NewsHour (PBS)
egen o_w_natlnewsnotnh = rmean(o_w_natlnewsabc o_w_natlnewscbs o_w_natlnewsnbc)
recode o_w_natlnewsnotnh (0=0) (.=.) (*=1), gen(o_natlnewsnotnh)
label var o_natlnewsnotnh "Watched Any National News Yesterday (not News Hour), 1=Yes [October]"

*Watched Any Late Local News
egen o_w_latelocalnews = rmean(o_w_latelocalnewsabc o_w_latelocalnewscbs o_w_latelocalnewsnbc o_w_latelocalnewsfox)
recode o_w_latelocalnews (0=0) (.=.) (*=1), gen(o_latelocalnews)
label var o_latelocalnews "Watched Any Late Local News Yesterday, 1=Yes [October]"

*Watched Any Local News (Evening or Late)
egen o_w_locnews = rmean(o_latelocalnews o_localnews)
recode o_w_locnews (0=0) (.=.) (*=1), gen(o_locnews)
label var o_locnews "Watched Any Local News Yesterday (Evening or Late), 1=Yes [October]"

*Total Hours of TV News Last Night
gen o_totalnews = o_localnews+o_natlnews+o_latelocalnews
label var o_totalnews "Total Amount of News Watching Yesterday (0 to 3) [October]"

*BASELINE
run "TV Grids/tvgrid_baseline_abc.do"
run "TV Grids/tvgrid_baseline_cbs.do"
run "TV Grids/tvgrid_baseline_nbc.do"
run "TV Grids/tvgrid_baseline_fox.do"
run "TV Grids/tvgrid_baseline_pbs.do"

*Indicator for how many hours of ABC TV
gen b_howmuchtv_abc = (b_abc500*.5)+(b_abc530*.5)+(b_abc600*.5)+(b_abc630*.5)+b_abc700+b_abc800+b_abc900+b_abc1000+b_abc1100
label var b_howmuchtv_abc "Total Hours of TV Watching - ABC [Baseline]"

*Indicator for watched any news on ABC
gen b_w_anyeveningnewsabc = b_w_localnewsabc if b_howmuchtv_abc~=.
replace b_w_anyeveningnewsabc = 1 if b_w_natlnewsabc ==1
label var b_w_anyeveningnewsabc "Watched any evening news - ABC [Baseline]"

*Indicator for how many hours of NBC TV
gen b_howmuchtv_nbc = (b_nbc500*.5)+(b_nbc530*.5)+(b_nbc600*.5)+(b_nbc630*.5)+b_nbc700+b_nbc800+b_nbc900+b_nbc1000+b_nbc1100
label var b_howmuchtv_nbc "Total Hours of TV Watching - nbc [Baseline]"

*Indicator for watched any news on NBC
gen b_w_anyeveningnewsnbc = b_w_localnewsnbc if b_howmuchtv_nbc~=.
replace b_w_anyeveningnewsnbc = 1 if b_w_natlnewsnbc ==1
label var b_w_anyeveningnewsnbc "Watched any evening news - NBC [Baseline]"

*Indicator for how many hours of CBS TV
gen b_howmuchtv_cbs = (b_cbs500*.5)+(b_cbs530*.5)+(b_cbs600*.5)+(b_cbs630*.5)+b_cbs700+b_cbs800+b_cbs900+b_cbs1000+b_cbs1100
label var b_howmuchtv_cbs "Total Hours of TV Watching - cbs [Baseline]"

*Indicator for watched any news on CBS
gen b_w_anyeveningnewscbs = b_w_localnewscbs if b_howmuchtv_cbs~=.
replace b_w_anyeveningnewscbs = 1 if b_w_natlnewscbs ==1
label var b_w_anyeveningnewscbs "Watched any evening news - CBS [Baseline]"

*Indicator for how many hours of FOX TV
gen b_howmuchtv_fox = (b_fox500*.5)+(b_fox530*.5)+(b_fox600*.5)+(b_fox630*.5)+b_fox700+b_fox800+b_fox900+b_fox1000+b_fox1100
label var b_howmuchtv_fox "Total Hours of TV Watching - fox [Baseline]"

*Indicator for how many hours of PBS TV
gen b_howmuchtv_pbs = (b_pbs500*.5)+(b_pbs530*.5)+(b_pbs600*.5)+(b_pbs630*.5)+b_pbs700+b_pbs800+b_pbs900+b_pbs1000+b_pbs1100
label var b_howmuchtv_pbs "Total Hours of TV Watching - pbs [Baseline]"

*How Much TV, Other
gen b_howmuchtv_other = (b_other500*.5)+(b_other530*.5)+(b_other600*.5)+(b_other630*.5)+b_other700+b_other800+b_other900+b_other1000+b_other1100
label var b_howmuchtv_other "Total Hours of TV Watching - Other [Baseline]"

*How Much TV, Overall Measure
gen b_howmuchtv_overall = b_howmuchtv_abc+b_howmuchtv_cbs+b_howmuchtv_nbc+b_howmuchtv_fox+b_howmuchtv_pbs+b_howmuchtv_other
label var b_howmuchtv_overall "Total Hours of TV Watching"
recode b_howmuchtv_overall (0=0) (1=1)(2=2)(3=3)(4=4)(5=5)(6=6)(7=7) (.=.) (*=7)

*How Much TV, Better Overall Measure (Total Hours of TV Watching)
foreach i in 500 530 600 630 700 800 900 1000 1100 {
gen b_w_tv`i'=0
replace b_w_tv`i'=. if odisp==3
replace b_w_tv`i'=1 if (b_abc`i'==1) | (b_nbc`i'==1) | (b_cbs`i'==1) | (b_fox`i'==1) | (b_pbs`i'==1) | (b_other`i'==1)
label var b_w_tv`i' "Watched TV `i'pm"
}
gen b_w_tv_total = (b_w_tv500*.5)+(b_w_tv530*.5)+(b_w_tv600*.5)+(b_w_tv630*.5)+b_w_tv700+b_w_tv800+b_w_tv900+b_w_tv1000+b_w_tv1100
label var b_w_tv_total "Total Hours of TV Watching Yesterday (0 to 7) [Baseline]"

** NEWS WATCHING INDICATORS
*Watched Any Evening News
egen b_w_anyeveningnews = rmean(b_w_anyeveningnewsabc b_w_anyeveningnewscbs b_w_anyeveningnewsnbc b_w_localnewsfox b_w_bbcworldnewspbs b_w_newspbs b_w_newshourpbs)
recode b_w_anyeveningnews (0=0) (.=.) (*=1), gen(b_anyeveningnews)
label var b_anyeveningnews "Watched Any (Local or National) Evening News Yesterday, 1=Yes [Baseline]"

*Watched Any Local News
egen b_w_localnews = rmean(b_w_localnewsabc b_w_localnewscbs b_w_localnewsnbc b_w_localnewsfox)
recode b_w_localnews (0=0) (.=.) (*=1), gen(b_localnews)
label var b_localnews "Watched Any Local Evening News Yesterday, 1=Yes [Baseline]"

*Watched Any National News
egen b_w_natlnews = rmean(b_w_natlnewsabc b_w_natlnewscbs b_w_natlnewsnbc b_w_newshourpbs)
recode b_w_natlnews (0=0) (.=.) (*=1), gen(b_natlnews)
label var b_natlnews "Watched Any National News Yesterday, 1=Yes [Baseline]"

*Watched Any National News - Not NewsHour (PBS)
egen b_w_natlnewsnotnh = rmean(b_w_natlnewsabc b_w_natlnewscbs b_w_natlnewsnbc)
recode b_w_natlnewsnotnh (0=0) (.=.) (*=1), gen(b_natlnewsnotnh)
label var b_natlnewsnotnh"Watched Any National News Yesterday (not News Hour), 1=Yes [Baseline]"

*Watched Any Late Local News
egen b_w_latelocalnews = rmean(b_w_latelocalnewsabc b_w_latelocalnewscbs b_w_latelocalnewsnbc b_w_latelocalnewsfox)
recode b_w_latelocalnews (0=0) (.=.) (*=1), gen(b_latelocalnews)
label var b_latelocalnews "Watched Any Late Local News Yesterday, 1=Yes [Baseline]"

*Watched Any Local News (Evening or Late)
egen b_w_locnews = rmean(b_latelocalnews b_localnews)
recode b_w_locnews (0=0) (.=.) (*=1), gen(b_locnews)
label var b_locnews "Watched Any Local News Yesterday (Evening or Late), 1=Yes [Baseline]"

*Total Hours of TV News Last Night
gen b_totalnews = b_localnews+b_natlnews+b_latelocalnews
label var b_totalnews "Total Amount of News Watching Yesterday (0 to 3) [Baseline]"

**********************************************************
** TABLES FOR APR - POLITICAL INFORMATION & PERSONALITY **
**********************************************************
*CA omitted; white omitted; moderates omitted (when ideology included)
*State and day of week of survey taken fixed effects suppressed (i.e., not outregged)

* Summary Statistics for entire CCAP sample (for Appendix - Table A3)
set more 1
sum b_polinterest o_polinterest o_govinterest poltrivia b_tvnews b_inetnews m_newspaper b_tvpoltalk b_tvsatire b_tvdaytalk b_tvltnght b_natlnews o_natlnews b_locnews o_locnews b_w_tv_total o_w_tv_total BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired [aweight=psweight]
outsum b_polinterest o_polinterest o_govinterest poltrivia b_tvnews b_inetnews m_newspaper b_tvpoltalk b_tvsatire b_tvdaytalk b_tvltnght b_natlnews o_natlnews b_locnews o_locnews b_w_tv_total o_w_tv_total [aweight=psweight] using "appendixtableA3", bracket replace
outsum BF_* female r_white r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired unemployed [aweight=psweight] using "appendixtableA3", bracket append

* Set sample
set more 1
reg b_polinterest o_polinterest o_govinterest poltrivia b_tvnews b_inetnews m_newspaper anynewsconslw amtnews b_tvpoltalk b_tvsatire b_tvdaytalk b_tvltnght b_natlnews o_natlnews b_locnews o_locnews b_w_tv_total o_w_tv_total BF_* if day_oct_s>1 & day_base_s>1 & employedmis==0
gen insample=e(sample)
*drop WY
drop if stateC_51==1
*N=8,664
keep if insample==1
*drop HI/AK, monday/saturday vars
drop stateC_2 stateC_12 stateC_51 day_base_C_2 day_base_C_3

***************
* B5 APPENDIX *
***************
  * Correlations between Big 5 traits and control variables (Appendix Table A1 & A2)
corr BF_* female r_white r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired unemployed [aweight=psweight]
  * TIPI Item Correlations
*Big Five - conscientiousness
pwcorr b_p_dependable b_p_disorganized_R [aweight=psweight]
*Big Five - openness to experiences
pwcorr b_p_open b_p_conventional_R [aweight=psweight]
*Big Five - agreeableness
pwcorr b_p_sympathetic b_p_critical_R [aweight=psweight]
*Big Five - emotional stability
pwcorr b_p_calm b_p_anxious_R [aweight=psweight]
*Big Five - extraversion
pwcorr b_p_extraverted b_p_reserved_R [aweight=psweight]

***************
*** TABLE 2 ***
***************
set more 1
sum b_polinterest o_polinterest o_govinterest poltrivia b_tvnews b_inetnews m_newspaper b_tvpoltalk b_tvsatire b_tvdaytalk b_tvltnght b_natlnews o_natlnews b_locnews o_locnews b_w_tv_total o_w_tv_total BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired [aweight=psweight]
outsum b_polinterest o_polinterest o_govinterest poltrivia b_tvnews b_inetnews m_newspaper b_tvpoltalk b_tvsatire b_tvdaytalk b_tvltnght b_natlnews o_natlnews b_locnews o_locnews b_w_tv_total o_w_tv_total [aweight=psweight] using "Table2", bracket replace
outsum BF_* female r_white r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired unemployed [aweight=psweight] using "Table2", bracket append

***************
*** TABLE 3 ***
***************
set more 1
foreach i in b_polinterest o_polinterest o_govinterest poltrivia {
if "`i'"=="poltrivia"{
	*reported model
reg `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired using "Table3.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "F/Chi-squared test: Joint Significance of Big Five", r(F), "Prob > F or chi-squared", r(p)) append

     *stripped down model
reg `i' BF_* female r_black r_hispanic r_other age age2 stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
outreg BF_* female r_black r_hispanic r_other age age2 using "altT3_appendixtableA4.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "F/Chi-squared test: Joint Significance of Big Five", r(F), "Prob > F or chi-squared", r(p)) append
     *controlling for ideology
reg `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis ideol* stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired ideol* using "altT3_appendixtableA4.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "F/Chi-squared test: Joint Significance of Big Five", r(F), "Prob > F or chi-squared", r(p)) append
}

else{
	*reported model
ologit `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired  income incomemis stateC_* day_base_C_* [aweight=psweight] if insample==1, cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
if "`i'"=="b_polinterest"{
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired  using "Table3.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "F/Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > F or chi-squared", r(p)) replace
}
else{
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired  using "Table3.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "F/Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > F or chi-squared", r(p)) append
}
	*stripped down model
ologit `i' BF_* female r_black r_hispanic r_other age age2 stateC_* day_base_C_* [aweight=psweight] if insample==1, cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
if "`i'"=="b_polinterest"{
outreg BF_* female r_black r_hispanic r_other age age2 using "altT3_appendixtableA4.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "F/Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > F or chi-squared", r(p)) replace
}
else{
outreg BF_* female r_black r_hispanic r_other age age2 using "altT3_appendixtableA4.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "F/Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > F or chi-squared", r(p)) append
}
     *controlling for ideology
ologit `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired  income incomemis ideol* stateC_* day_base_C_* [aweight=psweight] if insample==1, cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired  ideol* using "altT3_appendixtableA4.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "F/Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > F or chi-squared", r(p)) append
}
}

**** TO GRAB CUTPOINTS
/*
foreach i in b_polinterest o_polinterest o_govinterest {
ologit `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
}

ologit b_polinterest BF_* female r_black r_hispanic r_other age age2 stateC_* day_base_C_* [aweight=psweight] if insample==1, cluster(profile66)
ologit b_polinterest BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired  income incomemis ideol* stateC_* day_base_C_* [aweight=psweight] if insample==1, cluster(profile66)
ologit o_polinterest BF_* female r_black r_hispanic r_other age age2 stateC_* day_base_C_* [aweight=psweight] if insample==1, cluster(profile66)
ologit o_polinterest BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired  income incomemis ideol* stateC_* day_base_C_* [aweight=psweight] if insample==1, cluster(profile66)
ologit o_govinterest BF_* female r_black r_hispanic r_other age age2 stateC_* day_base_C_* [aweight=psweight] if insample==1, cluster(profile66)
ologit o_govinterest BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired  income incomemis ideol* stateC_* day_base_C_* [aweight=psweight] if insample==1, cluster(profile66)
*/

***************
*** TABLE 5 ***
***************
set more 1
foreach i in b_tvnews b_inetnews m_newspaper {
	*reported model
logit `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
if "`i'"=="b_tvnews"{
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired using "Table5.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) replace
}
else{
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired using "Table5.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) append
}
     *stripped down model
logit `i' BF_* female r_black r_hispanic r_other age age2 stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
if "`i'"=="b_tvnews"{
outreg BF_* female r_black r_hispanic r_other age age2 using "altT5_appendixtableA5.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) replace
}
else{
outreg BF_* female r_black r_hispanic r_other age age2 using "altT5_appendixtableA5.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) append
}
     *controlling for ideology
logit `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis ideol* stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired ideol* using "altT5_appendixtableA5.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) append
}

***************
*** TABLE 7 ***
***************
set more 1
foreach i in b_tvnews b_tvpoltalk b_tvdaytalk b_tvsatire b_tvltnght {

	*reported model
logit `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
if "`i'"=="b_tvnews"{
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired using "Table7.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) replace
}
else{
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired using "Table7.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) append
}
     *stripped down model
logit `i' BF_* female r_black r_hispanic r_other age age2 stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
if "`i'"=="b_tvnews"{
outreg BF_* female r_black r_hispanic r_other age age2 using "altT7_appendixtableA6.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) replace
}
else{
outreg BF_* female r_black r_hispanic r_other age age2 using "altT7_appendixtableA6.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) append
}
     *controlling for ideology
logit `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis ideol* stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired ideol* using "altT7_appendixtableA6.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) append
}

***************
*** TABLE 8 ***
***************
set more 1
foreach i in b_natlnews o_natlnews b_locnews o_locnews {
	*reported model
logit `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
if "`i'"=="b_natlnews"{
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired using "Table8.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) replace
}
else{
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired using "Table8.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) append
}
     *stripped down model
logit `i' BF_* female r_black r_hispanic r_other age age2 stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
if "`i'"=="b_natlnews"{
outreg BF_* female r_black r_hispanic r_other age age2 using "altT8_appendixtableA7.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) replace
}
else{
outreg BF_* female r_black r_hispanic r_other age age2 using "altT8_appendixtableA7.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) append
}
     *controlling for ideology
logit `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis ideol* stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired ideol* using "altT8_appendixtableA7.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "Chi-squared test: Joint Significance of Big Five", r(chi2), "Prob > chi-squared", r(p)) append
}

***************
*** TABLE A8 ***
***************
* How Much TV Watching, Various Networks (plus "Other")
set more 1
foreach i in b_w_tv_total o_w_tv_total {
	*reported model
reg `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
test BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion
if "`i'"=="b_w_tv_total"{
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired using "appendixtableA8.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "F test: Joint Significance of Big Five", r(F), "Prob > F", r(p)) replace
}
else{
outreg BF_* female r_black r_hispanic r_other age age2 educ income incomemis fulltime parttime retired using "appendixtableA8.out", se bracket rdec(3) addstat(Fixed State Effects, 1, "F test: Joint Significance of Big Five", r(F), "Prob > F", r(p)) append
}
}

************************
*** Marginal Effects ***
************************
* Table 4 (for models presented in Table 3)
set more 1
foreach i in b_polinterest o_polinterest o_govinterest {
ologit `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis stateC_* day_base_C_* [aweight=psweight] if insample==1, cluster(profile66)
foreach v in BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion educ income {
if "`v'"=="income"{
sum `v' if incomemis!=1
}
else{
sum `v'
}
local sd2=`r(sd)'*2
 prchange `v', x(age=50.25139 age2=25.252022 educ=3.427709 income=8.675282 female==1 fulltime==1 BF_conscientiousness=.7650702 BF_openness=.6955362 BF_agreeableness=.7077487 BF_stability=.6729946 BF_extraversion=.5136258) rest(min) fromto delta(`sd2') nobase
 matrix base=r(predval)
if "`i'"=="o_govinterest"{
 matrix mfx=r(change4)
 matrix baseval=base[1,4]
}
else{
 matrix mfx=r(change3)
 matrix baseval=base[1,3]
}
if "`v'"=="BF_conscientiousness"{
 matrix submfx=baseval[1,1]
}
 matrix submfx=submfx\(mfx[9,1]/baseval[1,1])
}
if "`i'"=="b_polinterest"{
matrix full==submfx
}
else{
matrix full==full,submfx
}
}

reg poltrivia BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis stateC_* day_base_C_* [aweight=psweight] if insample==1, cluster(profile66)
sum poltrivia [aweight=psweight] if insample==1
matrix submfx=r(mean)
foreach v in BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion educ income {
if "`v'"=="income"{
sum `v' if incomemis!=1
}
else{
sum `v'
}
local sd2=`r(sd)'*2
lincom `v'*`sd2'
matrix submfx=submfx\r(estimate)
}
matrix full==full,submfx

matrix list full
svmat full, names(full_)
outsheet full_* using mfxtable4.csv,comma replace
drop full_*

*Table 6 (for models presented in Table 5, 7, & 8)
set more 1
foreach i in b_tvnews b_inetnews m_newspaper b_tvpoltalk b_tvdaytalk b_tvsatire b_tvltnght b_natlnews o_natlnews b_locnews o_locnews {
logit `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis stateC_* day_base_C_* [pweight=psweight], cluster(profile66)
logit `i' BF_* female r_black r_hispanic r_other age age2 educ fulltime parttime retired income incomemis stateC_* day_base_C_* [pweight=psweight] if e(sample)==1, cluster(profile66)
foreach v in BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion educ income {
if "`v'"=="income"{
sum `v' if incomemis!=1
}
else{
sum `v'
}
local sd2=`r(sd)'*2
 prchange `v', x(age=50.25139 age2=25.252022 educ=3.427709 income=8.675282 female==1 fulltime==1 BF_conscientiousness=.7650702 BF_openness=.6955362 BF_agreeableness=.7077487 BF_stability=.6729946 BF_extraversion=.5136258) rest(min) fromto delta(`sd2') nobase
 matrix base=r(predval)
 matrix mfx=r(change)
if "`v'"=="BF_conscientiousness"{
 matrix submfx=base[1,2]
}
 matrix submfx=submfx\(mfx[9,1]/base[1,2])
}
if "`i'"=="b_tvnews"{
matrix full==submfx
}
else{
matrix full==full,submfx
}
}
matrix list full
svmat full, names(full_)
outsheet full_* using mfxtable6.csv,comma replace
drop full_*
